@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::RJBS;
 BEGIN {
-  $Dist::Zilla::PluginBundle::RJBS::VERSION = '0.101040';
+  $Dist::Zilla::PluginBundle::RJBS::VERSION = '0.101270';
 }
 # ABSTRACT: BeLike::RJBS when you build your dists
 
@@ -34,9 +34,19 @@ has is_task => (
   default => sub { $_[0]->payload->{is_task} },
 );
 
+has weaver_config => (
+  is      => 'ro',
+  isa     => 'Str',
+  lazy    => 1,
+  default => sub { $_[0]->payload->{weaver_config} || '@RJBS' },
+);
+
 sub configure {
   my ($self) = @_;
 
+  $self->log_fatal("you must not specify both weaver_config and is_task")
+    if $self->is_task and $self->weaver_config ne '@RJBS';
+
   $self->add_bundle('@Basic');
 
   my $v_format = $self->is_task
@@ -67,9 +77,13 @@ sub configure {
     Repository
   ));
 
-  $self->is_task
-    ? $self->add_plugins('TaskWeaver')
-    : $self->add_plugins([ PodWeaver => { config_plugin => '@RJBS' } ]);
+  if ($self->is_task) {
+    $self->add_plugins('TaskWeaver');
+  } else {
+    $self->add_plugins([
+      PodWeaver => { config_plugin => $self->weaver_config }
+    ]);
+  }
 
   $self->add_bundle('@Git' => { tag_format => '%v' });
 }
@@ -87,7 +101,7 @@ Dist::Zilla::PluginBundle::RJBS - BeLike::RJBS when you build your dists
 
 =head1 VERSION
 
-version 0.101040
+version 0.101270
 
 =head1 DESCRIPTION
 
